Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(308)

Unified Diff: runtime/vm/flow_graph_builder.h

Issue 10805008: Revert "Revert "Introduce Goto instructions to the flow graph."" (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/flow_graph_allocator.cc ('k') | runtime/vm/flow_graph_builder.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/flow_graph_builder.h
diff --git a/runtime/vm/flow_graph_builder.h b/runtime/vm/flow_graph_builder.h
index fe4585dfd368cf1b2b6b4347943a3f36adb00189..f2d95a653e477a1a0d58d22112539bcae4bf33c6 100644
--- a/runtime/vm/flow_graph_builder.h
+++ b/runtime/vm/flow_graph_builder.h
@@ -122,9 +122,12 @@ class EffectGraphVisitor : public AstNodeVisitor {
UseVal* Bind(Computation* computation);
// Append a computation with no uses. Assumes this graph is open.
void Do(Computation* computation);
// Append a single (non-Bind, non-Do) instruction. Assumes this graph is
// open.
void AddInstruction(Instruction* instruction);
+ // Append a Goto (unconditional control flow) instruction and close
+ // the graph fragment. Assumes this graph fragment is open.
+ void Goto(JoinEntryInstr* join);
// Append a 'diamond' branch and join to this graph, depending on which
// parts are reachable. Assumes this graph is open.
« no previous file with comments | « runtime/vm/flow_graph_allocator.cc ('k') | runtime/vm/flow_graph_builder.cc » ('j') | no next file with comments »
@@ -122,9 +122,12 @@ class EffectGraphVisitor : public AstNodeVisitor {
// Append a computation with no uses. Assumes this graph is open.
void Do(Computation* computation);
- // Append a single (non-Bind, non-Do) instruction. Assumes this graph is
- // open.
+ // Append a single (non-Definition, non-Entry) instruction. Assumes this
+ // graph is open.
void AddInstruction(Instruction* instruction);

Powered by Google App Engine
This is Rietveld 408576698